=============
Release Notes
=============

See the :ref:`version numbers<version-numbers>` page for more
information about the version numbering scheme.

Latest Branch Release
=====================

.. after carbon releases, replace :ref:`Release Candidate` with the following:
   |current_release_doc|

:ref:`Release Candidate <release-candidate>`

Previous Releases
=================

.. releasestree::
    :maxdepth: 1
    :glob:

    2016.11.*
    2016.3.*
    2015.8.*
    2015.5.*
    2014.7.*
    2014.1.*
    0.*

.. seealso:: :ref:`Legacy salt-cloud release docs <legacy-salt-cloud-release-notes>`

.. seealso:: :ref:`Legacy salt-api release docs <legacy-salt-api-release-notes>`
